@@ -12,25 +12,32 @@ class FileRegistry:
     def __init__(self, kind, name, ftype='csv', rootpath='', path=''):
         self.name = name
         if rootpath == '':
-            rootpath = '/Volumes/GoogleDrive/My Drive/__Data/'
+            self.rootpath = '/Volumes/GoogleDrive/My Drive/__Data/'
+        else:
+            self.rootpath = rootpath
+
         if kind == 'options':
-            self.path = rootpath + 'Premind_Light/Xignite/Options/' + path + '/'
+            self.path = self.rootpath + 'Xignite/Options/' + path + '/'
         elif kind == 'options_main':
-            self.path = rootpath + 'Premind_Light/Xignite/OptionsMain/' + path + '/'
+            self.path = self.rootpath + 'Xignite/OptionsMain/' + path + '/'
         elif kind == 'daily_price':
-            self.path = rootpath + 'Premind_Light/Xignite/DailyPrice/' + path + '/'
+            self.path = self.rootpath + 'Xignite/DailyPrice/' + path + '/'
+        elif kind == 'price_file_list':
+            self.path = self.rootpath + 'Xignite/PriceFileList/' + path + '/'
         elif kind == 'xlsx':
-            self.path = rootpath + '__Premind/6. Product-Tech/14. FraudArb' + path + '/'
+            self.path = self.rootpath + '__Premind/6. Product-Tech/14. FraudArb' + path + '/'
         elif kind == 'historic':
-            self.path = rootpath + '__Premind/6. Product-Tech/14. FraudArb/HistoricData' + path + '/'
+            self.path = self.rootpath + '__Premind/6. Product-Tech/14. FraudArb/HistoricData' + path + '/'
         elif kind == 'historic_ticker':
-            self.path = rootpath + '__Premind/6. Product-Tech/14. FraudArb/Articles' + path + '/'
+            self.path = self.rootpath + '__Premind/6. Product-Tech/14. FraudArb/Articles' + path + '/'
         elif kind == 'ticker':
-            self.path = rootpath + '__Python/Premind_Light/Analytics/Analytics_Cloud/Analytics_Docker/data/FraudArb/Tickers' + path + '/'
+            self.path = self.rootpath + '__Python/Premind_Light/Analytics/Analytics_Cloud/Analytics_Docker/data/FraudArb/Tickers' + path + '/'
         elif kind == 'TradingDates':
-            self.path = rootpath + 'Core/' + kind + path + '/'
+            self.path = self.rootpath + 'Core/' + kind + path + '/'
         elif kind == 'wordanalysis':
-            self.path = rootpath + kind + path + '/'
+            self.path = self.rootpath + kind + path + '/'
+        elif kind == 'Stocks':
+            self.path = self.rootpath + 'Core/' + kind + path + '/'
 
         if ftype == "":
             self.fullpath = self.path + name
